@@ -15,39 +15,34 @@
 
 since_packages <- function(date, position, lib = .libPaths()){
 
-  # retrieving packages' paths
   pack_paths <- fs::dir_ls(lib)
 
+  mod_time <- file.mtime(pack_paths)
 
-  # retrieving information about the packages
-  pack_info <- fs::file_info(pack_paths)
-
-
-  # transforming date time format to date only
-  pack_info$modification_time <- as.Date(pack_info$modification_time)
-
+  mod_time <- as.Date(lubridate::ymd_hms(mod_time))
 
+  data <- data.frame(pack_paths, mod_time)
 
 
   if(position == "at"){
 
-    packs <- pack_info[pack_info$modification_time == as.Date(date), ]
+    packs <- data[data$mod_time == as.Date(date), ]
 
 
   } else if (position == "before") {
 
-    packs <- pack_info[pack_info$modification_time < as.Date(date), ]
+    packs <- data[data$mod_time < as.Date(date), ]
 
 
   } else {
 
-    packs <- pack_info[pack_info$modification_time > as.Date(date), ]
+    packs <- data[data$mod_time > as.Date(date), ]
 
   }
 
 
   # getting the names of the packages (which is the last part of the path)
-  pack_names <-  sapply(fs::path_split(packs$path), utils::tail, 1)
+  pack_names <-  sapply(fs::path_split(packs$pack_paths), utils::tail, 1)
 
 
   if(length(pack_names) == 0){
